@@ -1,5 +1,5 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -81,9 +81,9 @@ gboolean      password_get(const gchar *user,
 			   guint16 port,
 			   gchar **password);
 
-void		  account_signatures_matchlist_create		(void);
-void		  account_signatures_matchlist_delete		(void);
-gboolean	  account_signatures_matchlist_str_found	(const gchar *str, const gchar *format);
-gboolean	  account_signatures_matchlist_nchar_found	(const gchar *str, const gchar *format);
+void		  account_sigsep_matchlist_create	  (void);
+void		  account_sigsep_matchlist_delete	  (void);
+gboolean	  account_sigsep_matchlist_str_found  (const gchar *str, const gchar *format);
+gboolean	  account_sigsep_matchlist_nchar_found    (const gchar *str, const gchar *format);
 
 #endif /* __ACCOUNT_H__ */
