@@ -1,11 +1,11 @@
 /*
  * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright 		(C) 2001 Match Grun
+ * Copyright (C) 2001-2022 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
- * 		(at your option) any later version.
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 /*
@@ -52,7 +51,9 @@ struct _AddressBookFile {
 AddressBookFile *addrbook_create_book	( void );
 
 void addrbook_free_book			( AddressBookFile *book );
+#ifdef DEBUG_ADDRBOOK
 void addrbook_dump_book			( AddressBookFile *book, FILE *stream );
+#endif
 void addrbook_set_name			( AddressBookFile *book, const gchar *value );
 void addrbook_set_path			( AddressBookFile *book, const gchar *value );
 void addrbook_set_file			( AddressBookFile *book, const gchar *value );
