@@ -1,5 +1,5 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 #define LOG_H
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include <glib.h>
@@ -29,7 +29,8 @@
 #define LOG_APPEND_TEXT_HOOKLIST "log_append_text"
 #define DEBUG_FILTERING_APPEND_TEXT_HOOKLIST "debug_append_text"
 
-#define LOG_TIME_LEN 11
+#define LOG_TIME_FORMAT "[%Y-%m-%d %H:%M:%S] "
+#define LOG_TIME_LEN 22
 
 typedef enum
 {
@@ -67,6 +68,7 @@ void set_log_title(LogInstance instance, gchar *title);
 gchar *get_log_title(LogInstance instance);
 void set_log_prefs(LogInstance instance, int* logwin_width, int* logwin_height);
 void get_log_prefs(LogInstance instance, int** logwin_width, int** logwin_height);
+gboolean get_log_error_capability(LogInstance instance);
 void log_print		(LogInstance instance, const gchar *format, ...) G_GNUC_PRINTF(2, 3);
 void log_message	(LogInstance instance, const gchar *format, ...) G_GNUC_PRINTF(2, 3);
 void log_warning	(LogInstance instance, const gchar *format, ...) G_GNUC_PRINTF(2, 3);
