@@ -1,11 +1,11 @@
 /*
- * Sylpheed -- regexp pattern matching utilities
+ * Claws Mail -- regexp pattern matching utilities
  * Copyright (C) 2001 Thomas Link, Hiroyuki Yamamoto
  *                    Modified by Melvin Hadasht.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 
@@ -26,12 +26,6 @@
 #include <regex.h>
 #include <glib.h>
 
-/* Precompile the preg buffer for the rexp regexp string. See regex man for the
- * meaning of cflags.  
- */
-
-int string_match_precompile (gchar *rexp, regex_t *preg, int cflags);
-
 /* remove from txt the substrings matching the regexp in the precompiled preg buffer.  
  * The result is stored in the preallocated buf buffer which maximal length
  * is buflen.
