@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto  and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2018 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,15 +27,9 @@
 
 #define PACKAGE			"claws-mail"
 #define PACKAGE_FRIENDLY	"Claws Mail"
-#define VERSION			"3.9.2"
-#define RELEASE_VERSION		"3.9.2"
-#define PROG_VERSION		PACKAGE_FRIENDLY" "VERSION_GIT_FULL
-#ifdef USE_MAINTAINER_MODE
-#define PROG_VERSION_FRIENDLY	PROG_VERSION
-#else
-#define PROG_VERSION_FRIENDLY	PACKAGE_FRIENDLY" "RELEASE_VERSION
-#endif
-#define VERSION_NUMERIC		MAKE_NUMERIC_VERSION(3, 9, \
-						     2, 0)
-#define VERSION_GIT_FULL	"3.9.2"
+#define VERSION			"4.3.1"
+#define PROG_VERSION		PACKAGE_FRIENDLY" "VERSION
+#define VERSION_NUMERIC		MAKE_NUMERIC_VERSION(4, 3, \
+						     1, 0)
+#define VERSION_GIT_FULL	"4.3.1"
 #endif /* __VERSION_H__ */
