@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2021 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,16 +28,12 @@ typedef struct _AttachInfo	AttachInfo;
 
 #include "procmsg.h"
 #include "procmime.h"
-#ifndef USE_NEW_ADDRBOOK
-#include "addressbook.h"
-#endif
 #include "prefs_account.h"
 #include "undo.h"
 #include "toolbar.h"
-#include "messageview.h"
 #include "codeconv.h"
 #include "template.h"
-#include "textview.h"
+#include "viewtypes.h"
 #include "folder.h"
 
 #ifdef USE_ENCHANT
@@ -82,6 +78,18 @@ typedef enum
 	COMPOSE_REEDIT
 } ComposeMode;
 
+typedef enum
+{
+	COMPOSE_QUEUE_SUCCESS = 0,
+	COMPOSE_QUEUE_ERROR_NO_MSG = -1,
+	COMPOSE_QUEUE_ERROR_WITH_ERRNO = -2,
+	COMPOSE_QUEUE_ERROR_SIGNING_FAILED = -3,
+	COMPOSE_QUEUE_ERROR_ENCRYPT_FAILED = -4,
+	COMPOSE_QUEUE_ERROR_CHAR_CONVERSION = -5,
+	COMPOSE_QUEUE_ERROR_NO_ENCRYPTION_KEY = -6,
+	COMPOSE_QUEUE_SIGNING_CANCELLED = -7
+} ComposeQueueResult;
+
 typedef enum {
 	PREF_ACCOUNT,
 	PREF_FOLDER,
@@ -140,9 +148,6 @@ struct _Compose
 	GtkWidget *scrolledwin;
 	GtkWidget *text;
 	GtkWidget *from_name;
-#if !GTK_CHECK_VERSION(2,12,0)
-	GtkTooltips *tooltips;
-#endif
 
 	GtkWidget *focused_editable;
 
@@ -194,6 +199,7 @@ struct _Compose
 	gboolean use_signing;
 	gboolean use_encryption;
 	gchar *privacy_system;
+	gchar *encdata;
 
 	gboolean modified;
 
@@ -216,9 +222,9 @@ struct _Compose
 
 	/* external editor */
 	gchar      *exteditor_file;
-	pid_t       exteditor_pid;
-	GIOChannel *exteditor_ch;
+	GPid        exteditor_pid;
 	gint        exteditor_tag;
+	GtkWidget  *exteditor_socket;
 
  	/* Priority */
  	gint priority;
@@ -227,7 +233,7 @@ struct _Compose
 	
 	gboolean remove_references;
 
-	guint draft_timeout_tag;
+	gint64 draft_timeout_tag;
 	
 	GtkTextTag *no_wrap_tag;
 	GtkTextTag *no_join_tag;
@@ -238,22 +244,31 @@ struct _Compose
 	GtkTextTag *uri_tag;
 
 	gboolean automatic_break;
-	GMutex *mutex;
+	GMutex mutex;
+	gint close_timeout_tag;
 	gchar *orig_charset;
 	gint set_cursor_pos;
-	
+
 	gboolean updating;
 	gboolean deferred_destroy;
 	ComposeMode rmode;
 	GtkWidget *first_combo;
 	GtkWidget *first_entry;
-	
+
 	GtkUIManager *ui_manager;
+
+	gint folder_update_callback_id;
 #if USE_ENCHANT
         /* GNU/aspell spell checker */
         GtkAspell *gtkaspell;
 	GtkWidget *aspell_options_menu;
 #endif
+
+#ifdef USE_LDAP
+	/* List of addressbook ifaces which we disabled, and will
+	 * enable in compose_destroy. */
+	GSList *passworded_ldap_servers;
+#endif
 };
 
 struct _AttachInfo
@@ -264,6 +279,7 @@ struct _AttachInfo
 	gchar *name;
 	goffset size;
 	gchar *charset;
+	gboolean insert;
 };
 
 typedef enum
@@ -275,7 +291,7 @@ typedef enum
 } ComposeDraftAction;
 
 /*#warning FIXME_GTK2 */
-/* attache_files will be locale encode */
+/* attach_files will be locale encode */
 Compose *compose_new			(PrefsAccount	*account,
 				 	 const gchar	*mailto,
 				 	 GList		*attach_files);
@@ -300,7 +316,7 @@ Compose *compose_redirect		(PrefsAccount	*account,
 Compose *compose_reedit			(MsgInfo	*msginfo,
 					 gboolean	 batch);
 
-GList *compose_get_compose_list		(void);
+const GList *compose_get_compose_list	(void);
 
 void compose_entry_append		(Compose	  *compose,
 					 const gchar	  *address,
@@ -334,7 +350,7 @@ gboolean compose_search_string			(Compose	*compose,
 gboolean compose_search_string_backward	(Compose	*compose,
 						 const gchar	*str,
 						 gboolean	 case_sens);
-gint compose_queue			(Compose *compose, 
+ComposeQueueResult compose_queue	(Compose *compose,
 					 gint *msgnum, 
 					 FolderItem **item, 
 					 gchar **msgpath,
@@ -345,4 +361,8 @@ void compose_clear_exit_drafts		(void);
 void compose_reopen_exit_drafts		(void);
 void compose_attach_from_list (Compose *compose, GList *file_list, gboolean free_data);
 void compose_check_for_email_account(Compose *compose);
+
+void compose_use_signing(Compose *compose, gboolean use_signing);
+void compose_use_encryption(Compose *compose, gboolean use_encryption);
+
 #endif /* __COMPOSE_H__ */
