@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail Team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,13 +24,15 @@
 #include <gtk/gtk.h>
 
 typedef struct _PrefsPage PrefsPage;
+typedef struct _PrefsWindow PrefsWindow;
 
 typedef void (*PrefsCreateWidgetFunc) (PrefsPage *, GtkWindow *window, gpointer);
 typedef void (*PrefsDestroyWidgetFunc) (PrefsPage *);
 typedef void (*PrefsSavePageFunc) (PrefsPage *);
 typedef gboolean (*PrefsCanClosePageFunc) (PrefsPage *);
-typedef void (*PrefsOpenCallbackFunc) (GtkWindow *);
-typedef void (*PrefsCloseCallbackFunc) (GtkWindow *);
+typedef void (*PrefsOpenCallbackFunc) (PrefsWindow *);
+typedef void (*PrefsApplyCallbackFunc) (PrefsWindow *);
+typedef void (*PrefsCloseCallbackFunc) (PrefsWindow *);
 
 struct _PrefsPage
 {
@@ -45,6 +47,60 @@ struct _PrefsPage
 	PrefsCanClosePageFunc	  can_close;
 };
 
+enum {
+	PREFS_PAGE_TITLE,		/* page title */
+	PREFS_PAGE_DATA,		/* PrefsTreeNode data */
+	PREFS_PAGE_DATA_AUTO_FREE,	/* auto free for PREFS_PAGE_DATA */
+	PREFS_PAGE_WEIGHT,		/* weight */
+	PREFS_PAGE_INDEX,		/* index in original page list */
+	N_PREFS_PAGE_COLUMNS
+};
+
+typedef struct _PrefsTreeNode PrefsTreeNode;
+
+struct _PrefsWindow
+{
+	GtkWidget *window;
+	GtkWidget *vbox;
+	GtkWidget *paned;
+	GtkWidget *scrolledwindow1;
+	GtkWidget *tree_view;
+	GtkWidget *table2;
+	GtkWidget *pagelabel;
+	GtkWidget *labelframe;
+	GtkWidget *vbox2;
+	GtkWidget *notebook;
+	GtkWidget *confirm_area;
+	GtkWidget *ok_btn;
+	GtkWidget *cancel_btn;
+	GtkWidget *apply_btn;
+	gint *save_width;
+	gint *save_height;
+	PrefsCloseCallbackFunc open_cb;
+	PrefsApplyCallbackFunc apply_cb;
+	PrefsCloseCallbackFunc close_cb;
+	gint dialog_response; /* Useful for close_cb callbacks */
+
+	GtkWidget *empty_page;
+
+	gpointer   	 data;
+	GSList	  	*prefs_pages;
+	GDestroyNotify func;
+};
+
+enum
+{
+	PREFSWINDOW_RESPONSE_CANCEL,
+	PREFSWINDOW_RESPONSE_OK,
+	PREFSWINDOW_RESPONSE_APPLY
+};
+
+struct _PrefsTreeNode
+{
+	PrefsPage *page;
+	gfloat     treeweight; /* GTK2: not used */
+};
+
 void prefswindow_open_full		(const gchar *title, 
 					 GSList *prefs_pages,
 					 gpointer data,
@@ -52,6 +108,7 @@ void prefswindow_open_full		(const gchar *title,
 					 gint *save_width, gint *save_height,
 					 gboolean preload_pages,
 					 PrefsOpenCallbackFunc open_cb,
+					 PrefsApplyCallbackFunc apply_cb,
 					 PrefsCloseCallbackFunc close_cb);
 
 void prefswindow_open			(const gchar *title, 
@@ -59,6 +116,7 @@ void prefswindow_open			(const gchar *title,
 					 gpointer data,
 					 gint *save_width, gint *save_height,
 					 PrefsOpenCallbackFunc open_cb,
+					 PrefsApplyCallbackFunc apply_cb,
 					 PrefsCloseCallbackFunc close_cb);
 
 #endif
