@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2003-2009 Match Grun and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 2003-2022 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 /*
@@ -64,7 +63,6 @@ struct _LdapControl {
 	gint      port;
 	gchar     *baseDN;
 	gchar     *bindDN;
-	gchar     *bindPass;
 	gint      maxEntries;
 	gint      timeOut;
 	gint      maxQueryAge;
@@ -87,7 +85,9 @@ void ldapctl_set_host		( LdapControl* ctl, const gchar *value );
 void ldapctl_set_port		( LdapControl* ctl, const gint value );
 void ldapctl_set_base_dn	( LdapControl* ctl, const gchar *value );
 void ldapctl_set_bind_dn	( LdapControl* ctl, const gchar *value );
-void ldapctl_set_bind_password	( LdapControl* ctl, const gchar *value );
+void ldapctl_set_bind_password	
+	( LdapControl* ctl, const gchar *value, gboolean encrypt, gboolean change );
+gchar* ldapctl_get_bind_password ( LdapControl* ctl );
 void ldapctl_set_max_entries	( LdapControl* ctl, const gint value );
 void ldapctl_set_timeout	( LdapControl* ctl, const gint value );
 void ldapctl_set_max_query_age	( LdapControl* ctl, const gint value );
@@ -98,7 +98,9 @@ GList *ldapctl_get_criteria_list( const LdapControl* ctl );
 void ldapctl_criteria_list_clear( LdapControl *ctl );
 void ldapctl_criteria_list_add	( LdapControl *ctl, gchar *attr );
 void ldapctl_free		( LdapControl *ctl );
+#ifdef DEBUG_LDAP
 void ldapctl_print		( const LdapControl *ctl, FILE *stream );
+#endif
 void ldapctl_copy		( const LdapControl *ctlFrom,
 				  LdapControl *ctlTo );
 gchar *ldapctl_format_criteria	( LdapControl *ctl, const gchar *searchVal );
