@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2023 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,28 +22,17 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#ifdef MAEMO
-#ifdef CHINOOK
-#include <hildon/hildon-program.h>
-#else
-#include <hildon-widgets/hildon-program.h>
-#include <hildon-widgets/hildon-window.h>
-#endif
-#endif
 #include <sys/time.h>
 
 extern gchar *prog_version;
 extern gboolean debug_mode;
 
-#ifdef MAEMO
-extern HildonProgram *hildon_program;
-#endif
-
 typedef struct _SessionStats SessionStats;
 
 struct _SessionStats
 {
 	gint received;
+	gint spam;
 	gint sent;
 	gint replied;
 	gint forwarded;
