@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2021 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,16 +20,12 @@
 #ifndef MIMEVIEW_H
 #define MIMEVIEW_H
 
-typedef struct _MimeView		MimeView;
 typedef struct _MimeViewerFactory 	MimeViewerFactory;
 typedef struct _MimeViewer 		MimeViewer;
 
 #include <glib.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
-#ifdef USE_PTHREAD
-#include <pthread.h>
-#endif
 
 #include "textview.h"
 #include "messageview.h"
@@ -42,22 +38,6 @@ typedef enum
 	MIMEVIEW_VIEWER
 } MimeViewType;
 
-#ifdef USE_PTHREAD
-typedef struct _SigCheckData SigCheckData;
-struct _SigCheckData
-{
-	pthread_t th;
-	pthread_t cancel_th;
-	gboolean th_init;
-	gboolean cancel_th_init;
-
-	MimeInfo *siginfo;
-	gboolean free_after_use;
-	gboolean destroy_mimeview;
-	gboolean timeout;
-};
-#endif
-
 struct _MimeView
 {
 	GtkWidget *hbox;
@@ -67,10 +47,11 @@ struct _MimeView
 	GtkWidget *mime_notebook;
 	GtkWidget *ctree_mainbox;
 	GtkWidget *icon_scroll;
-	GtkWidget *icon_vbox;
+	GtkWidget *icon_grid;
 	GtkWidget *icon_mainbox;
 	GtkWidget *mime_toggle;
 	GtkWidget *scrollbutton;
+	GtkWidget *arrow;
 	MimeViewType type;
 	gboolean ctree_mode;
 
@@ -93,18 +74,16 @@ struct _MimeView
 
 	gint icon_count;
 	MainWindow *mainwin;
-#if !GTK_CHECK_VERSION(2,12,0)
-	GtkTooltips *tooltips;
-#endif
 
 	NoticeView *siginfoview;
 	MimeInfo *siginfo;
 	MimeInfo *spec_part;
 	GtkUIManager *ui_manager;
 	GtkActionGroup *action_group;
-#ifdef USE_PTHREAD
-	SigCheckData *check_data;
-#endif
+	gboolean signed_part;
+
+	GCancellable *sig_check_cancellable;
+	guint sig_check_timeout_tag;
 };
 
 struct _MimeViewerFactory
@@ -149,6 +128,8 @@ void mimeview_show_message	(MimeView	*mimeview,
 				 const gchar	*file);
 gboolean mimeview_show_part	(MimeView 	*mimeview, 
 				 MimeInfo 	*partinfo);
+void mimeview_show_part_as_text (MimeView *mimeview,
+				 MimeInfo *partinfo);
 void mimeview_destroy		(MimeView	*mimeview);
 void mimeview_update		(MimeView 	*mimeview);
 void mimeview_clear		(MimeView	*mimeview);
@@ -177,6 +158,17 @@ gboolean mimeview_has_viewer_for_content_type
 					(MimeView	*mimeview,
 					 const gchar	*content_type);
 gboolean mimeview_tree_is_empty		(MimeView 	*mimeview);
+void mimeview_save_as		(MimeView	*mimeview);
+void mimeview_display_as_text	(MimeView	*mimeview);
+void mimeview_launch		(MimeView	*mimeview,
+				 MimeInfo	*partinfo);
+#ifndef G_OS_WIN32
+void mimeview_open_with		(MimeView	*mimeview);
+#endif
+void mimeview_check_signature(MimeView *mimeview);
+void mimeview_select_next_part(MimeView *mimeview);
+void mimeview_select_prev_part(MimeView *mimeview);
+
 
 #ifdef __cplusplus
 }
