@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2018 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,14 +14,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 #ifndef __PROCMSG_H__
 #define __PROCMSG_H__
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include <glib.h>
@@ -29,18 +28,8 @@
 #include <time.h>
 #include <sys/types.h>
 #include <string.h>
-#include "utils.h"
-
-typedef struct _MsgInfo			MsgInfo;
-typedef struct _MsgFlags		MsgFlags;
-typedef struct _MsgFileInfo     	MsgFileInfo;
-typedef struct _MsgInfoUpdate 		MsgInfoUpdate;
-typedef struct _MailFilteringData	MailFilteringData;
-
-typedef struct _MsgInfoExtraData	MsgInfoExtraData;
-
-typedef GSList MsgInfoList;
-typedef GSList MsgNumberList;
+#include "common/utils.h"
+#include "proctypes.h"
 
 #define MSG_NEW			(1U << 0)
 #define MSG_UNREAD		(1U << 1)
@@ -92,11 +81,9 @@ typedef GSList MsgNumberList;
 #define MSG_RETRCPT_GOT		(1U << 17)   /* got return receipt */
  	
 /* RESERVED */
-#define	MSG_RESERVED_CLAWS	(1U << 30)   /* for claws-mail */
+#define	MSG_RESERVED_CLAWS	(1U << 30)   /* for Claws Mail */
 #define	MSG_RESERVED		(1U << 31)
 
-typedef guint32 MsgPermFlags;
-
 #define MSG_MOVE		(1U << 0)
 #define MSG_COPY		(1U << 1)
 #define MSG_MOVE_DONE		(1U << 15)		
@@ -110,8 +97,6 @@ typedef guint32 MsgPermFlags;
 #define MSG_HAS_ATTACHMENT	(1U << 30)
 #define MSG_SCANNED		(1U << 31)
 
-typedef guint32 MsgTmpFlags;
-
 #define MSG_CACHED_FLAG_MASK	(MSG_MULTIPART | MSG_ENCRYPTED | MSG_SIGNED | MSG_HAS_ATTACHMENT | MSG_SCANNED)
 
 #define MSG_SET_FLAGS(msg, flags)	{ (msg) |= (flags); }
@@ -158,9 +143,7 @@ typedef guint32 MsgTmpFlags;
 #define MSG_IS_SCANNED(msg)		(((msg).tmp_flags & MSG_SCANNED) != 0)
 
 /* Claws related flags */
-#define MSG_IS_REALLY_DELETED(msg)	(((msg).perm_flags & MSG_REALLY_DELETED) != 0)
 #define MSG_IS_IGNORE_THREAD(msg)	(((msg).perm_flags & MSG_IGNORE_THREAD) != 0)
-#define MSG_IS_RETRCPT_PENDING(msg)	(((msg).perm_flags & MSG_RETRCPT_PENDING) != 0)
 #define MSG_IS_RETRCPT_SENT(msg)	(((msg).perm_flags & MSG_RETRCPT_SENT) != 0)
 #define MSG_IS_RETRCPT_GOT(msg)		(((msg).perm_flags & MSG_RETRCPT_GOT) != 0)
 #define MSG_IS_SPAM(msg)		(((msg).perm_flags & MSG_SPAM) != 0)
@@ -177,7 +160,7 @@ typedef enum {
 	MSGINFO_UPDATE_DELETED = 1 << 1
 } MsgInfoUpdateFlags;
 
-#include "procmime.h"
+#include "prefs_account.h"
 #include "prefs_filtering.h"
 #include "folder.h"
 
@@ -245,6 +228,7 @@ struct _MsgInfo
 	gint total_size;
 	gint planned_download;
 
+	/* list of tags ids */
 	GSList *tags;
 
 	MsgInfoExtraData *extradata;
@@ -252,12 +236,13 @@ struct _MsgInfo
 
 struct _MsgInfoExtraData
 {
-	gchar *xface;
-	gchar *face;
+	GSList *avatars;
 
 	gchar *dispositionnotificationto;
 	gchar *returnreceiptto;
 
+	gchar *resent_from;
+
 	/* used only for partially received messages */
 	gchar *partial_recv;
 	gchar *account_server;
@@ -272,6 +257,12 @@ struct _MsgInfoExtraData
  	gchar *list_owner;
 };
 
+struct _MsgInfoAvatar
+{
+	gint avatar_id;
+	gchar *avatar_src;
+};
+
 struct _MsgFileInfo
 {
 	MsgInfo *msginfo;
@@ -293,9 +284,17 @@ struct _MailFilteringData
 	PrefsAccount *account;
 };
 
+struct	_AvatarCaptureData
+{
+	MsgInfo *msginfo;
+	const gchar *header;
+	const gchar *content;
+};
+
 GSList *procmsg_read_cache		(FolderItem	*item,
 					 gboolean	 scan_file);
-void	procmsg_msg_list_free		(GSList		*mlist);
+void	procmsg_msg_list_free		(MsgInfoList	*mlist);
+MsgNumberList *procmsg_get_number_list_for_msgs(MsgInfoList *msglist);
 void	procmsg_get_mark_sum		(const gchar	*folder,
 					 gint		*new_msgs,
 					 gint		*unread_msgs,
@@ -317,7 +316,8 @@ gchar  *procmsg_get_message_file_full	(MsgInfo	*msginfo,
 					 gboolean	 get_body);
 GSList *procmsg_get_message_file_list	(MsgInfoList	*mlist);
 void	procmsg_message_file_list_free	(MsgInfoList	*file_list);
-FILE   *procmsg_open_message		(MsgInfo	*msginfo);
+FILE   *procmsg_open_message		(MsgInfo	*msginfo,
+					 gboolean	skip_special_headers);
 gboolean procmsg_msg_exist		(MsgInfo	*msginfo);
 
 void	procmsg_get_filter_keyword	(MsgInfo	  *msginfo,
@@ -333,8 +333,6 @@ gint	procmsg_send_queue		(FolderItem	*queue,
 gboolean procmsg_queue_lock		(gchar		**errstr);
 void     procmsg_queue_unlock		(void);
 gboolean procmsg_queue_is_empty	(FolderItem *queue);
-void	procmsg_print_message		(MsgInfo	*msginfo,
-					 const gchar	*cmdline);
 
 MsgInfo *procmsg_msginfo_new		();
 MsgInfo *procmsg_msginfo_new_ref	(MsgInfo 	*msginfo);
@@ -343,7 +341,7 @@ MsgInfo *procmsg_msginfo_get_full_info	(MsgInfo	*msginfo);
 MsgInfo *procmsg_msginfo_get_full_info_from_file
 					(MsgInfo *msginfo, 
 					const gchar *file);
-void	 procmsg_msginfo_free		(MsgInfo	*msginfo);
+void	 procmsg_msginfo_free		(MsgInfo	**msginfo);
 guint	 procmsg_msginfo_memusage	(MsgInfo	*msginfo);
 
 gint procmsg_send_message_queue_with_lock(const gchar *file,
@@ -372,6 +370,7 @@ void procmsg_msginfo_change_flags	(MsgInfo *msginfo,
 gint procmsg_remove_special_headers	(const gchar 	*in, 
 					 const gchar 	*out);
 
+gint procmsg_save_to_outbox(FolderItem *outbox, const gchar *file);
 gboolean procmsg_msg_has_flagged_parent	(MsgInfo 	*info,
 					 MsgPermFlags    perm_flags);
 gboolean procmsg_msg_has_marked_parent	(MsgInfo	*info);
@@ -400,4 +399,9 @@ gchar *procmsg_msginfo_get_tags_str(MsgInfo *msginfo);
 void procmsg_msginfo_update_tags(MsgInfo *msginfo, gboolean set, gint id);
 void procmsg_msginfo_clear_tags(MsgInfo *msginfo);
 void procmsg_msginfo_commit_tags(GSList *msglist);
+MsgInfo *procmsg_get_msginfo_from_identifier(const gchar *id);
+gchar *procmsg_msginfo_get_identifier(MsgInfo *msginfo);
+
+gchar *procmsg_msginfo_get_avatar(MsgInfo *msginfo, gint type);
+void procmsg_msginfo_add_avatar(MsgInfo *msginfo, gint type, const gchar *data);
 #endif /* __PROCMSG_H__ */
