@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,5 +41,7 @@ gint send_message_smtp_full	(PrefsAccount *ac_prefs,
 				 GSList *to_list, 
 				 FILE *fp, 
 				 gboolean keep_session);
+void send_cancel	(void);
+gboolean send_is_active	(void);
 
 #endif /* __SEND_H__ */
