@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2016 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2023 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,15 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
+typedef enum
+{
+	PRIV_PIXMAP_CLAWS_MAIL_ICON,
+	PRIV_PIXMAP_CLAWS_MAIL_ICON_64,
+	PRIV_PIXMAP_CLAWS_MAIL_LOGO,
+	PRIV_PIXMAP_EMPTY,              /* last entry */
+	N_PRIV_PIXMAPS
+} PrivPixmap;
+
 typedef enum
 {
 	STOCK_PIXMAP_ADDR_ONE,
@@ -163,15 +172,12 @@ typedef enum
 	STOCK_PIXMAP_PRIVACY_EMBLEM_FAILED,
 	STOCK_PIXMAP_PRIVACY_EMBLEM_WARN,
 	STOCK_PIXMAP_MIME_MESSAGE,
-	STOCK_PIXMAP_CLAWS_MAIL_ICON,
-	STOCK_PIXMAP_CLAWS_MAIL_ICON_64,
 	STOCK_PIXMAP_READ,
 	STOCK_PIXMAP_DELETE,
 	STOCK_PIXMAP_DELETE_DUP,
 	STOCK_PIXMAP_CANCEL,
 	STOCK_PIXMAP_TRASH,
 	STOCK_PIXMAP_MAIL_COMPOSE_LOGO,
-	STOCK_PIXMAP_CLAWS_MAIL_LOGO,
 	STOCK_PIXMAP_DIR_NOSELECT_CLOSE, 
 	STOCK_PIXMAP_DIR_NOSELECT_CLOSE_MARK, 
 	STOCK_PIXMAP_DIR_NOSELECT_OPEN, 
@@ -235,12 +241,15 @@ typedef enum {
 	OVERLAY_BOTTOM_RIGHT
 } OverlayPosition;
 
+GtkWidget *priv_pixmap_widget	(PrivPixmap	  icon);
+PrivPixmap priv_pixmap_get_icon    (gchar *file);
+gint priv_pixbuf_gdk		(PrivPixmap icon, GdkPixbuf **pixbuf);
+
 GtkWidget *stock_pixmap_widget	(StockPixmap	  icon);
 gint stock_pixbuf_gdk		(StockPixmap icon, GdkPixbuf **pixbuf);
 
 GList *stock_pixmap_themes_list_new	(void);
 void stock_pixmap_themes_list_free	(GList *list);
-void stock_pixmap_invalidate_all_icons	(void);
 gchar *stock_pixmap_get_name         (StockPixmap icon);
 StockPixmap stock_pixmap_get_icon    (gchar *file);
 GtkWidget *stock_pixmap_widget_with_overlay (StockPixmap	 icon,
